import { Directive, Input, HostListener, NgModule } from '@angular/core';

class NgxMaskInputDirective {
    constructor() {
        //
        this.mask = '.';
    }
    //
    onKeyPress($event) {
        return this.filterInput($event);
    }
    //
    onPaste($event) {
        return this.filterInput($event);
    }
    //
    filterInput(event) {
        const $input = event._input || event.target;
        if (event.ctrlKey || event.altKey) {
            return;
        }
        let value = null;
        let regex = null;
        switch (event._type || event.type) {
            case 'keypress':
                const pressedKey = event.charCode || event.keyCode || 0;
                if (pressedKey === 13) {
                    return true;
                }
                if ([8, 9, 13, 35, 36, 37, 39, 46].indexOf(pressedKey) > -1) {
                    if (event.charCode === 0 && event.keyCode === pressedKey) {
                        return true;
                    }
                }
                value = String.fromCharCode(pressedKey);
                regex = new RegExp(this.mask);
                break;
            case 'paste':
                $input.dataset.value_before_paste = event.target.value;
                setTimeout(() => {
                    event._type = 'after_paste';
                    event._input = $input;
                    this.filterInput(event);
                }, 0);
                return true;
            case 'after_paste':
                value = $input.value;
                regex = new RegExp(`^(${this.mask})+$`);
                break;
            default:
                event.preventDefault();
                return false;
        }
        if (regex.test(value)) {
            return true;
        }
        if (event._type === 'after_paste') {
            $input.value = $input.dataset.value_before_paste;
        }
        event.preventDefault();
        return false;
    }
}
NgxMaskInputDirective.decorators = [
    { type: Directive, args: [{
                selector: 'input[mask]'
            },] }
];
NgxMaskInputDirective.propDecorators = {
    mask: [{ type: Input }],
    onKeyPress: [{ type: HostListener, args: ['keypress', ['$event'],] }],
    onPaste: [{ type: HostListener, args: ['paste', ['$event'],] }]
};

class NgxMaskInputModule {
}
NgxMaskInputModule.decorators = [
    { type: NgModule, args: [{
                declarations: [NgxMaskInputDirective],
                exports: [NgxMaskInputDirective]
            },] }
];

/*
 * Public API Surface of ngx-mask-input
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxMaskInputDirective, NgxMaskInputModule };
//# sourceMappingURL=ngx-mask-input.js.map
